@@ -29,3 +29,6 @@ class Filesystem(FileIO):
         except DistutilsFileError:
             # If it's a file 
             copy_file(from_path, to_path)
+
+    def get_modification_time(self, path):
+        return os.path.getmtime(path)
